@@ -75,25 +75,27 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(32, 4, 16)
 SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
 
 #if defined(SIMDE_ARM_NEON_A32V7_NATIVE)
-  typedef    int8x8_t    simde_int8x8_t;
-  typedef   int16x4_t   simde_int16x4_t;
-  typedef   int32x2_t   simde_int32x2_t;
-  typedef   int64x1_t   simde_int64x1_t;
-  typedef   uint8x8_t   simde_uint8x8_t;
-  typedef  uint16x4_t  simde_uint16x4_t;
-  typedef  uint32x2_t  simde_uint32x2_t;
-  typedef  uint64x1_t  simde_uint64x1_t;
-  typedef float32x2_t simde_float32x2_t;
+  typedef     float32_t     simde_float32_t;
 
-  typedef   int8x16_t   simde_int8x16_t;
-  typedef   int16x8_t   simde_int16x8_t;
-  typedef   int32x4_t   simde_int32x4_t;
-  typedef   int64x2_t   simde_int64x2_t;
-  typedef  uint8x16_t  simde_uint8x16_t;
-  typedef  uint16x8_t  simde_uint16x8_t;
-  typedef  uint32x4_t  simde_uint32x4_t;
-  typedef  uint64x2_t  simde_uint64x2_t;
-  typedef float32x4_t simde_float32x4_t;
+  typedef      int8x8_t      simde_int8x8_t;
+  typedef     int16x4_t     simde_int16x4_t;
+  typedef     int32x2_t     simde_int32x2_t;
+  typedef     int64x1_t     simde_int64x1_t;
+  typedef     uint8x8_t     simde_uint8x8_t;
+  typedef    uint16x4_t    simde_uint16x4_t;
+  typedef    uint32x2_t    simde_uint32x2_t;
+  typedef    uint64x1_t    simde_uint64x1_t;
+  typedef   float32x2_t   simde_float32x2_t;
+
+  typedef     int8x16_t     simde_int8x16_t;
+  typedef     int16x8_t     simde_int16x8_t;
+  typedef     int32x4_t     simde_int32x4_t;
+  typedef     int64x2_t     simde_int64x2_t;
+  typedef    uint8x16_t    simde_uint8x16_t;
+  typedef    uint16x8_t    simde_uint16x8_t;
+  typedef    uint32x4_t    simde_uint32x4_t;
+  typedef    uint64x2_t    simde_uint64x2_t;
+  typedef   float32x4_t   simde_float32x4_t;
 
   typedef    int8x8x2_t    simde_int8x8x2_t;
   typedef   int16x4x2_t   simde_int16x4x2_t;
@@ -115,31 +117,70 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
   typedef  uint64x2x2_t  simde_uint64x2x2_t;
   typedef float32x4x2_t simde_float32x4x2_t;
 
-  typedef   float32_t   simde_float32_t;
+  typedef    int8x8x3_t    simde_int8x8x3_t;
+  typedef   int16x4x3_t   simde_int16x4x3_t;
+  typedef   int32x2x3_t   simde_int32x2x3_t;
+  typedef   int64x1x3_t   simde_int64x1x3_t;
+  typedef   uint8x8x3_t   simde_uint8x8x3_t;
+  typedef  uint16x4x3_t  simde_uint16x4x3_t;
+  typedef  uint32x2x3_t  simde_uint32x2x3_t;
+  typedef  uint64x1x3_t  simde_uint64x1x3_t;
+  typedef float32x2x3_t simde_float32x2x3_t;
+
+  typedef   int8x16x3_t   simde_int8x16x3_t;
+  typedef   int16x8x3_t   simde_int16x8x3_t;
+  typedef   int32x4x3_t   simde_int32x4x3_t;
+  typedef   int64x2x3_t   simde_int64x2x3_t;
+  typedef  uint8x16x3_t  simde_uint8x16x3_t;
+  typedef  uint16x8x3_t  simde_uint16x8x3_t;
+  typedef  uint32x4x3_t  simde_uint32x4x3_t;
+  typedef  uint64x2x3_t  simde_uint64x2x3_t;
+  typedef float32x4x3_t simde_float32x4x3_t;
+
+  typedef    int8x8x4_t    simde_int8x8x4_t;
+  typedef   int16x4x4_t   simde_int16x4x4_t;
+  typedef   int32x2x4_t   simde_int32x2x4_t;
+  typedef   int64x1x4_t   simde_int64x1x4_t;
+  typedef   uint8x8x4_t   simde_uint8x8x4_t;
+  typedef  uint16x4x4_t  simde_uint16x4x4_t;
+  typedef  uint32x2x4_t  simde_uint32x2x4_t;
+  typedef  uint64x1x4_t  simde_uint64x1x4_t;
+  typedef float32x2x4_t simde_float32x2x4_t;
+
+  typedef   int8x16x4_t   simde_int8x16x4_t;
+  typedef   int16x8x4_t   simde_int16x8x4_t;
+  typedef   int32x4x4_t   simde_int32x4x4_t;
+  typedef   int64x2x4_t   simde_int64x2x4_t;
+  typedef  uint8x16x4_t  simde_uint8x16x4_t;
+  typedef  uint16x8x4_t  simde_uint16x8x4_t;
+  typedef  uint32x4x4_t  simde_uint32x4x4_t;
+  typedef  uint64x2x4_t  simde_uint64x2x4_t;
+  typedef float32x4x4_t simde_float32x4x4_t;
 
   #if defined(SIMDE_ARM_NEON_A64V8_NATIVE)
-    typedef float64x1_t simde_float64x1_t;
-    typedef float64x2_t simde_float64x2_t;
-    typedef   float64_t   simde_float64_t;
-
+    typedef     float64_t     simde_float64_t;
+    typedef   float64x1_t   simde_float64x1_t;
+    typedef   float64x2_t   simde_float64x2_t;
     typedef float64x1x2_t simde_float64x1x2_t;
     typedef float64x2x2_t simde_float64x2x2_t;
-    typedef   float64x2_t   simde_float64x2_t;
+    typedef float64x1x3_t simde_float64x1x3_t;
+    typedef float64x2x3_t simde_float64x2x3_t;
+    typedef float64x1x4_t simde_float64x1x4_t;
+    typedef float64x2x4_t simde_float64x2x4_t;
   #else
     #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1
     #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2
     #define SIMDE_ARM_NEON_NEED_PORTABLE_F64
-
-    #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2
-    #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2
+    #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN
+    #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN
   #endif
 #elif defined(SIMDE_ARCH_X86) || defined(SIMDE_ARCH_AMD64)
   #define SIMDE_ARM_NEON_NEED_PORTABLE_F32
   #define SIMDE_ARM_NEON_NEED_PORTABLE_F64
 
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_VX2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_VXN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN
 
   #if defined(SIMDE_X86_MMX_NATIVE)
     typedef __m64    simde_int8x8_t;
@@ -198,9 +239,9 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
 
   #define SIMDE_ARM_NEON_NEED_PORTABLE_64BIT
 
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_VX2
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_VXN
 
   typedef v128_t   simde_int8x16_t;
   typedef v128_t   simde_int16x8_t;
@@ -212,28 +253,30 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
   typedef v128_t  simde_uint64x2_t;
   typedef v128_t simde_float32x4_t;
   typedef v128_t simde_float64x2_t;
-#elif defined(SIMDE_POWER_ALTIVEC_P5_NATIVE)
+#elif defined(SIMDE_POWER_ALTIVEC_P6_NATIVE)
   #define SIMDE_ARM_NEON_NEED_PORTABLE_F32
   #define SIMDE_ARM_NEON_NEED_PORTABLE_F64
 
   #define SIMDE_ARM_NEON_NEED_PORTABLE_64BIT
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_VX2
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_VXN
 
   typedef SIMDE_POWER_ALTIVEC_VECTOR(signed char)          simde_int8x16_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(signed short)         simde_int16x8_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(signed int)           simde_int32x4_t;
-  typedef SIMDE_POWER_ALTIVEC_VECTOR(signed long long)     simde_int64x2_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(unsigned char)       simde_uint8x16_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(unsigned short)      simde_uint16x8_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(unsigned int)        simde_uint32x4_t;
-  typedef SIMDE_POWER_ALTIVEC_VECTOR(unsigned long long)  simde_uint64x2_t;
   typedef SIMDE_POWER_ALTIVEC_VECTOR(float)              simde_float32x4_t;
 
   #if defined(SIMDE_POWER_ALTIVEC_P7_NATIVE)
+    typedef SIMDE_POWER_ALTIVEC_VECTOR(signed long long)       simde_int64x2_t;
+    typedef SIMDE_POWER_ALTIVEC_VECTOR(unsigned long long)     simde_uint64x2_t;
     typedef SIMDE_ALIGN(16) SIMDE_POWER_ALTIVEC_VECTOR(double) simde_float64x2_t;
   #else
+    #define SIMDE_ARM_NEON_NEED_PORTABLE_I64X2
+    #define SIMDE_ARM_NEON_NEED_PORTABLE_U64X2
     #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2
   #endif
 #else
@@ -242,9 +285,9 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
   #define SIMDE_ARM_NEON_NEED_PORTABLE_64BIT
   #define SIMDE_ARM_NEON_NEED_PORTABLE_128BIT
 
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_VX2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2
-  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_VXN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN
+  #define SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN
 #endif
 
 #if defined(SIMDE_ARM_NEON_NEED_PORTABLE_I8X8) || defined(SIMDE_ARM_NEON_NEED_PORTABLE_64BIT)
@@ -316,7 +359,7 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
   typedef simde_float64 simde_float64_t;
 #endif
 
-#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_VX2)
+#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_VXN) && !defined(SIMDE_BUG_INTEL_857088)
   typedef struct    simde_int8x8x2_t {
     simde_int8x8_t val[2];
   } simde_int8x8x2_t;
@@ -372,66 +415,241 @@ SIMDE_ARM_NEON_TYPE_FLOAT_DEFINE_(64, 2, 16)
   typedef struct simde_float32x4x2_t {
     simde_float32x4_t val[2];
   } simde_float32x4x2_t;
+
+  typedef struct    simde_int8x8x3_t {
+    simde_int8x8_t val[3];
+  } simde_int8x8x3_t;
+  typedef struct   simde_int16x4x3_t {
+    simde_int16x4_t val[3];
+  } simde_int16x4x3_t;
+  typedef struct   simde_int32x2x3_t {
+    simde_int32x2_t val[3];
+  } simde_int32x2x3_t;
+  typedef struct   simde_int64x1x3_t {
+    simde_int64x1_t val[3];
+  } simde_int64x1x3_t;
+  typedef struct   simde_uint8x8x3_t {
+    simde_uint8x8_t val[3];
+  } simde_uint8x8x3_t;
+  typedef struct  simde_uint16x4x3_t {
+    simde_uint16x4_t val[3];
+  } simde_uint16x4x3_t;
+  typedef struct  simde_uint32x2x3_t {
+    simde_uint32x2_t val[3];
+  } simde_uint32x2x3_t;
+  typedef struct  simde_uint64x1x3_t {
+    simde_uint64x1_t val[3];
+  } simde_uint64x1x3_t;
+  typedef struct simde_float32x2x3_t {
+    simde_float32x2_t val[3];
+  } simde_float32x2x3_t;
+
+  typedef struct   simde_int8x16x3_t {
+    simde_int8x16_t val[3];
+  } simde_int8x16x3_t;
+  typedef struct   simde_int16x8x3_t {
+    simde_int16x8_t val[3];
+  } simde_int16x8x3_t;
+  typedef struct   simde_int32x4x3_t {
+    simde_int32x4_t val[3];
+  } simde_int32x4x3_t;
+  typedef struct   simde_int64x2x3_t {
+    simde_int64x2_t val[3];
+  } simde_int64x2x3_t;
+  typedef struct  simde_uint8x16x3_t {
+    simde_uint8x16_t val[3];
+  } simde_uint8x16x3_t;
+  typedef struct  simde_uint16x8x3_t {
+    simde_uint16x8_t val[3];
+  } simde_uint16x8x3_t;
+  typedef struct  simde_uint32x4x3_t {
+    simde_uint32x4_t val[3];
+  } simde_uint32x4x3_t;
+  typedef struct  simde_uint64x2x3_t {
+    simde_uint64x2_t val[3];
+  } simde_uint64x2x3_t;
+  typedef struct simde_float32x4x3_t {
+    simde_float32x4_t val[3];
+  } simde_float32x4x3_t;
+
+  typedef struct    simde_int8x8x4_t {
+    simde_int8x8_t val[4];
+  } simde_int8x8x4_t;
+  typedef struct   simde_int16x4x4_t {
+    simde_int16x4_t val[4];
+  } simde_int16x4x4_t;
+  typedef struct   simde_int32x2x4_t {
+    simde_int32x2_t val[4];
+  } simde_int32x2x4_t;
+  typedef struct   simde_int64x1x4_t {
+    simde_int64x1_t val[4];
+  } simde_int64x1x4_t;
+  typedef struct   simde_uint8x8x4_t {
+    simde_uint8x8_t val[4];
+  } simde_uint8x8x4_t;
+  typedef struct  simde_uint16x4x4_t {
+    simde_uint16x4_t val[4];
+  } simde_uint16x4x4_t;
+  typedef struct  simde_uint32x2x4_t {
+    simde_uint32x2_t val[4];
+  } simde_uint32x2x4_t;
+  typedef struct  simde_uint64x1x4_t {
+    simde_uint64x1_t val[4];
+  } simde_uint64x1x4_t;
+  typedef struct simde_float32x2x4_t {
+    simde_float32x2_t val[4];
+  } simde_float32x2x4_t;
+
+  typedef struct   simde_int8x16x4_t {
+    simde_int8x16_t val[4];
+  } simde_int8x16x4_t;
+  typedef struct   simde_int16x8x4_t {
+    simde_int16x8_t val[4];
+  } simde_int16x8x4_t;
+  typedef struct   simde_int32x4x4_t {
+    simde_int32x4_t val[4];
+  } simde_int32x4x4_t;
+  typedef struct   simde_int64x2x4_t {
+    simde_int64x2_t val[4];
+  } simde_int64x2x4_t;
+  typedef struct  simde_uint8x16x4_t {
+    simde_uint8x16_t val[4];
+  } simde_uint8x16x4_t;
+  typedef struct  simde_uint16x8x4_t {
+    simde_uint16x8_t val[4];
+  } simde_uint16x8x4_t;
+  typedef struct  simde_uint32x4x4_t {
+    simde_uint32x4_t val[4];
+  } simde_uint32x4x4_t;
+  typedef struct  simde_uint64x2x4_t {
+    simde_uint64x2_t val[4];
+  } simde_uint64x2x4_t;
+  typedef struct simde_float32x4x4_t {
+    simde_float32x4_t val[4];
+  } simde_float32x4x4_t;
 #endif
 
-#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_F64X1X2)
+#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_F64X1XN)
   typedef struct   simde_float64x1x2_t {
     simde_float64x1_t val[2];
   } simde_float64x1x2_t;
+
+  typedef struct   simde_float64x1x3_t {
+    simde_float64x1_t val[3];
+  } simde_float64x1x3_t;
+
+  typedef struct   simde_float64x1x4_t {
+    simde_float64x1_t val[4];
+  } simde_float64x1x4_t;
 #endif
 
-#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_F64X2X2)
-typedef struct   simde_float64x2x2_t {
-  simde_float64x2_t val[2];
-} simde_float64x2x2_t;
+#if defined(SIMDE_ARM_NEON_NEED_PORTABLE_F64X2XN)
+  typedef struct   simde_float64x2x2_t {
+    simde_float64x2_t val[2];
+  } simde_float64x2x2_t;
+
+ typedef struct   simde_float64x2x3_t {
+   simde_float64x2_t val[3];
+ } simde_float64x2x3_t;
+
+ typedef struct   simde_float64x2x4_t {
+   simde_float64x2_t val[4];
+ } simde_float64x2x4_t;
 #endif
 
 #if defined(SIMDE_ARM_NEON_A32V7_ENABLE_NATIVE_ALIASES)
-  typedef    simde_int8x8_t    int8x8_t;
-  typedef   simde_int16x4_t   int16x4_t;
-  typedef   simde_int32x2_t   int32x2_t;
-  typedef   simde_int64x1_t   int64x1_t;
-  typedef   simde_uint8x8_t   uint8x8_t;
-  typedef  simde_uint16x4_t  uint16x4_t;
-  typedef  simde_uint32x2_t  uint32x2_t;
-  typedef  simde_uint64x1_t  uint64x1_t;
-  typedef simde_float32x2_t float32x2_t;
-  typedef   simde_int8x16_t   int8x16_t;
-  typedef   simde_int16x8_t   int16x8_t;
-  typedef   simde_int32x4_t   int32x4_t;
-  typedef   simde_int64x2_t   int64x2_t;
-  typedef  simde_uint8x16_t  uint8x16_t;
-  typedef  simde_uint16x8_t  uint16x8_t;
-  typedef  simde_uint32x4_t  uint32x4_t;
-  typedef  simde_uint64x2_t  uint64x2_t;
-  typedef simde_float32x4_t float32x4_t;
+  typedef   simde_float32_t     float32_t;
 
-  typedef    simde_int8x8x2_t    int8x8x2_t;
-  typedef   simde_int16x4x2_t   int16x4x2_t;
-  typedef   simde_int32x2x2_t   int32x2x2_t;
-  typedef   simde_int64x1x2_t   int64x1x2_t;
-  typedef   simde_uint8x8x2_t   uint8x8x2_t;
-  typedef  simde_uint16x4x2_t  uint16x4x2_t;
-  typedef  simde_uint32x2x2_t  uint32x2x2_t;
-  typedef  simde_uint64x1x2_t  uint64x1x2_t;
+  typedef    simde_int8x8_t      int8x8_t;
+  typedef   simde_int16x4_t     int16x4_t;
+  typedef   simde_int32x2_t     int32x2_t;
+  typedef   simde_int64x1_t     int64x1_t;
+  typedef   simde_uint8x8_t     uint8x8_t;
+  typedef  simde_uint16x4_t    uint16x4_t;
+  typedef  simde_uint32x2_t    uint32x2_t;
+  typedef  simde_uint64x1_t    uint64x1_t;
+  typedef simde_float32x2_t   float32x2_t;
+
+  typedef   simde_int8x16_t     int8x16_t;
+  typedef   simde_int16x8_t     int16x8_t;
+  typedef   simde_int32x4_t     int32x4_t;
+  typedef   simde_int64x2_t     int64x2_t;
+  typedef  simde_uint8x16_t    uint8x16_t;
+  typedef  simde_uint16x8_t    uint16x8_t;
+  typedef  simde_uint32x4_t    uint32x4_t;
+  typedef  simde_uint64x2_t    uint64x2_t;
+  typedef simde_float32x4_t   float32x4_t;
+
+  typedef  simde_int8x8x2_t    int8x8x2_t;
+  typedef simde_int16x4x2_t   int16x4x2_t;
+  typedef simde_int32x2x2_t   int32x2x2_t;
+  typedef simde_int64x1x2_t   int64x1x2_t;
+  typedef simde_uint8x8x2_t   uint8x8x2_t;
+  typedef simde_uint16x4x2_t  uint16x4x2_t;
+  typedef simde_uint32x2x2_t  uint32x2x2_t;
+  typedef simde_uint64x1x2_t  uint64x1x2_t;
   typedef simde_float32x2x2_t float32x2x2_t;
-  typedef   simde_int8x16x2_t   int8x16x2_t;
-  typedef   simde_int16x8x2_t   int16x8x2_t;
-  typedef   simde_int32x4x2_t   int32x4x2_t;
-  typedef   simde_int64x2x2_t   int64x2x2_t;
-  typedef  simde_uint8x16x2_t  uint8x16x2_t;
-  typedef  simde_uint16x8x2_t  uint16x8x2_t;
-  typedef  simde_uint32x4x2_t  uint32x4x2_t;
-  typedef  simde_uint64x2x2_t  uint64x2x2_t;
+
+  typedef simde_int8x16x2_t   int8x16x2_t;
+  typedef simde_int16x8x2_t   int16x8x2_t;
+  typedef simde_int32x4x2_t   int32x4x2_t;
+  typedef simde_int64x2x2_t   int64x2x2_t;
+  typedef simde_uint8x16x2_t  uint8x16x2_t;
+  typedef simde_uint16x8x2_t  uint16x8x2_t;
+  typedef simde_uint32x4x2_t  uint32x4x2_t;
+  typedef simde_uint64x2x2_t  uint64x2x2_t;
   typedef simde_float32x4x2_t float32x4x2_t;
 
+  typedef  simde_int8x8x3_t    int8x8x3_t;
+  typedef simde_int16x4x3_t   int16x4x3_t;
+  typedef simde_int32x2x3_t   int32x2x3_t;
+  typedef simde_int64x1x3_t   int64x1x3_t;
+  typedef simde_uint8x8x3_t   uint8x8x3_t;
+  typedef simde_uint16x4x3_t  uint16x4x3_t;
+  typedef simde_uint32x2x3_t  uint32x2x3_t;
+  typedef simde_uint64x1x3_t  uint64x1x3_t;
+  typedef simde_float32x2x3_t float32x2x3_t;
+
+  typedef simde_int8x16x3_t   int8x16x3_t;
+  typedef simde_int16x8x3_t   int16x8x3_t;
+  typedef simde_int32x4x3_t   int32x4x3_t;
+  typedef simde_int64x2x3_t   int64x2x3_t;
+  typedef simde_uint8x16x3_t  uint8x16x3_t;
+  typedef simde_uint16x8x3_t  uint16x8x3_t;
+  typedef simde_uint32x4x3_t  uint32x4x3_t;
+  typedef simde_uint64x2x3_t  uint64x2x3_t;
+  typedef simde_float32x4x3_t float32x4x3_t;
+
+  typedef  simde_int8x8x4_t    int8x8x4_t;
+  typedef simde_int16x4x4_t   int16x4x4_t;
+  typedef simde_int32x2x4_t   int32x2x4_t;
+  typedef simde_int64x1x4_t   int64x1x4_t;
+  typedef simde_uint8x8x4_t   uint8x8x4_t;
+  typedef simde_uint16x4x4_t  uint16x4x4_t;
+  typedef simde_uint32x2x4_t  uint32x2x4_t;
+  typedef simde_uint64x1x4_t  uint64x1x4_t;
+  typedef simde_float32x2x4_t float32x2x4_t;
+
+  typedef simde_int8x16x4_t   int8x16x4_t;
+  typedef simde_int16x8x4_t   int16x8x4_t;
+  typedef simde_int32x4x4_t   int32x4x4_t;
+  typedef simde_int64x2x4_t   int64x2x4_t;
+  typedef simde_uint8x16x4_t  uint8x16x4_t;
+  typedef simde_uint16x8x4_t  uint16x8x4_t;
+  typedef simde_uint32x4x4_t  uint32x4x4_t;
+  typedef simde_uint64x2x4_t  uint64x2x4_t;
+  typedef simde_float32x4x4_t float32x4x4_t;
 #endif
 #if defined(SIMDE_ARM_NEON_A64V8_ENABLE_NATIVE_ALIASES)
+  typedef   simde_float64_t     float64_t;
   typedef simde_float64x1_t   float64x1_t;
   typedef simde_float64x2_t   float64x2_t;
-
-  typedef  simde_uint64x1x2_t  uint64x1x2_t;
+  typedef simde_float64x1x2_t float64x1x2_t;
   typedef simde_float64x2x2_t float64x2x2_t;
+  typedef simde_float64x1x3_t float64x1x3_t;
+  typedef simde_float64x2x3_t float64x2x3_t;
+  typedef simde_float64x1x4_t float64x1x4_t;
+  typedef simde_float64x2x4_t float64x2x4_t;
 #endif
 
 #define SIMDE_ARM_NEON_TYPE_DEFINE_CONVERSIONS_(T) \
