@@ -213,7 +213,7 @@ simde_test_codegen_u64(size_t buf_len, char buf[HEDLEY_ARRAY_PARAM(buf_len)], ui
 static void
 simde_test_codegen_write_indent(int indent) {
   for (int i = 0 ; i < indent ; i++) {
-    fputs("  ", stdout);
+    fputs("  ", SIMDE_CODEGEN_FP);
   }
 }
 
@@ -300,7 +300,7 @@ SIMDE_TEST_CODEGEN_GENERATE_RANDOM_INT_FUNC_(uint64_t, u64)
       case SIMDE_TEST_VEC_POS_FIRST: \
         simde_test_codegen_write_indent(indent); \
         indent++; \
-        fputs("{ ", stdout); \
+        fputs("{ ", SIMDE_CODEGEN_FP); \
         break; \
       case SIMDE_TEST_VEC_POS_MIDDLE: \
       case SIMDE_TEST_VEC_POS_LAST: \
@@ -309,35 +309,35 @@ SIMDE_TEST_CODEGEN_GENERATE_RANDOM_INT_FUNC_(uint64_t, u64)
         break; \
     } \
  \
-    fputs("{ ", stdout); \
+    fputs("{ ", SIMDE_CODEGEN_FP); \
     for (size_t i = 0 ; i < elem_count ; i++) { \
       if (i != 0) { \
-        fputc(',', stdout); \
+        fputc(',', SIMDE_CODEGEN_FP); \
         if ((i % elements_per_line) == 0) { \
-          fputc('\n', stdout); \
+          fputc('\n', SIMDE_CODEGEN_FP); \
           simde_test_codegen_write_indent(indent + 1); \
         } else { \
-          fputc(' ', stdout); \
+          fputc(' ', SIMDE_CODEGEN_FP); \
         } \
       } \
  \
       char buf[53]; \
       simde_test_codegen_##symbol_identifier(sizeof(buf), buf, values[i]); \
-      fputs(buf, stdout); \
+      fputs(buf, SIMDE_CODEGEN_FP); \
     } \
-    fputs(" }", stdout); \
+    fputs(" }", SIMDE_CODEGEN_FP); \
  \
     switch (pos) { \
       case SIMDE_TEST_VEC_POS_FIRST: \
       case SIMDE_TEST_VEC_POS_MIDDLE: \
-        fputc(',', stdout); \
+        fputc(',', SIMDE_CODEGEN_FP); \
         break; \
       case SIMDE_TEST_VEC_POS_LAST: \
-        fputs(" },", stdout); \
+        fputs(" },", SIMDE_CODEGEN_FP); \
         break; \
     } \
  \
-    fputc('\n', stdout); \
+    fputc('\n', SIMDE_CODEGEN_FP); \
   }
 
 SIMDE_TEST_CODEGEN_GENERATE_WRITE_VECTOR_FUNC_(simde_float32, f32, 4)
@@ -358,7 +358,7 @@ SIMDE_TEST_CODEGEN_GENERATE_WRITE_VECTOR_FUNC_(uint64_t, u64, 4)
       case SIMDE_TEST_VEC_POS_FIRST: \
         simde_test_codegen_write_indent(indent); \
         indent++; \
-        fputs("{ ", stdout); \
+        fputs("{ ", SIMDE_CODEGEN_FP); \
         break; \
       case SIMDE_TEST_VEC_POS_MIDDLE: \
       case SIMDE_TEST_VEC_POS_LAST: \
@@ -370,20 +370,20 @@ SIMDE_TEST_CODEGEN_GENERATE_WRITE_VECTOR_FUNC_(uint64_t, u64, 4)
     { \
       char buf[53]; \
       simde_test_codegen_##symbol_identifier(sizeof(buf), buf, value); \
-      fputs(buf, stdout); \
+      fputs(buf, SIMDE_CODEGEN_FP); \
     } \
  \
     switch (pos) { \
       case SIMDE_TEST_VEC_POS_FIRST: \
       case SIMDE_TEST_VEC_POS_MIDDLE: \
-        fputc(',', stdout); \
+        fputc(',', SIMDE_CODEGEN_FP); \
         break; \
       case SIMDE_TEST_VEC_POS_LAST: \
-        fputs(" },", stdout); \
+        fputs(" },", SIMDE_CODEGEN_FP); \
         break; \
     } \
  \
-    fputc('\n', stdout); \
+    fputc('\n', SIMDE_CODEGEN_FP); \
   }
 
 SIMDE_TEST_CODEGEN_WRITE_SCALAR_FUNC_(int8_t,    i8)
@@ -397,6 +397,9 @@ SIMDE_TEST_CODEGEN_WRITE_SCALAR_FUNC_(uint64_t, u64)
 SIMDE_TEST_CODEGEN_WRITE_SCALAR_FUNC_(simde_float32, f32)
 SIMDE_TEST_CODEGEN_WRITE_SCALAR_FUNC_(simde_float64, f64)
 
+HEDLEY_DIAGNOSTIC_PUSH
+SIMDE_DIAGNOSTIC_DISABLE_FLOAT_EQUAL_
+
 static int
 simde_test_equal_f32(simde_float32 a, simde_float32 b, simde_float32 slop) {
   if (simde_math_isnan(a)) {
@@ -404,7 +407,15 @@ simde_test_equal_f32(simde_float32 a, simde_float32 b, simde_float32 slop) {
   } else if (simde_math_isinf(a)) {
     return !((a < b) || (a > b));
   } else {
-    return ((b > (a - slop)) && (b < (a + slop)));
+    simde_float32 lo = a - slop;
+    if (HEDLEY_UNLIKELY(lo == a))
+      lo = simde_math_nextafterf(a, -SIMDE_MATH_INFINITYF);
+
+    simde_float32 hi = a + slop;
+    if (HEDLEY_UNLIKELY(hi == a))
+      hi = simde_math_nextafterf(a, SIMDE_MATH_INFINITYF);
+
+    return ((b >= lo) && (b <= hi));
   }
 }
 
@@ -415,10 +426,30 @@ simde_test_equal_f64(simde_float64 a, simde_float64 b, simde_float64 slop) {
   } else if (simde_math_isinf(a)) {
     return !((a < b) || (a > b));
   } else {
-    return ((b > (a - slop)) && (b < (a + slop)));
+    simde_float64 lo = a - slop;
+    if (HEDLEY_UNLIKELY(lo == a))
+      lo = simde_math_nextafter(a, -SIMDE_MATH_INFINITY);
+
+    simde_float64 hi = a + slop;
+    if (HEDLEY_UNLIKELY(hi == a))
+      hi = simde_math_nextafter(a, SIMDE_MATH_INFINITY);
+
+    return ((b >= lo) && (b <= hi));
   }
 }
 
+HEDLEY_DIAGNOSTIC_POP
+
+static float
+simde_test_f32_precision_to_slop(int precision) {
+  return simde_math_powf(SIMDE_FLOAT32_C(10.0), -HEDLEY_STATIC_CAST(float, precision));
+}
+
+static double
+simde_test_f64_precision_to_slop(int precision) {
+  return simde_math_pow(SIMDE_FLOAT64_C(10.0), -HEDLEY_STATIC_CAST(double, precision));
+}
+
 static int
 simde_assert_equal_vf32_(
     size_t vec_len, simde_float32 const a[HEDLEY_ARRAY_PARAM(vec_len)], simde_float32 const b[HEDLEY_ARRAY_PARAM(vec_len)], simde_float32 slop,
@@ -432,7 +463,7 @@ simde_assert_equal_vf32_(
   }
   return 0;
 }
-#define simde_assert_equal_vf32(vec_len, a, b, precision) simde_assert_equal_vf32_(vec_len, a, b, 1e-##precision##f, __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_vf32(vec_len, a, b, precision) simde_assert_equal_vf32_(vec_len, a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
 
 static int
 simde_assert_equal_f32_(simde_float32 a, simde_float32 b, simde_float32 slop,
@@ -444,7 +475,7 @@ simde_assert_equal_f32_(simde_float32 a, simde_float32 b, simde_float32 slop,
   }
   return 0;
 }
-#define simde_assert_equal_f32(a, b, precision) simde_assert_equal_f32_(a, b, 1e-##precision##f, __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_f32(a, b, precision) simde_assert_equal_f32_(a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
 
 static int
 simde_assert_equal_vf64_(
@@ -459,7 +490,7 @@ simde_assert_equal_vf64_(
   }
   return 0;
 }
-#define simde_assert_equal_vf64(vec_len, a, b, precision) simde_assert_equal_vf64_(vec_len, a, b, 1e-##precision, __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_vf64(vec_len, a, b, precision) simde_assert_equal_vf64_(vec_len, a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
 
 static int
 simde_assert_equal_f64_(simde_float64 a, simde_float64 b, simde_float64 slop,
@@ -471,7 +502,7 @@ simde_assert_equal_f64_(simde_float64 a, simde_float64 b, simde_float64 slop,
   }
   return 0;
 }
-#define simde_assert_equal_f64(a, b, precision) simde_assert_equal_f64_(a, b, 1e-##precision, __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_f64(a, b, precision) simde_assert_equal_f64_(a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
 
 #define SIMDE_TEST_GENERATE_ASSERT_EQUAL_FUNC_(T, symbol_identifier, fmt) \
   static int \
@@ -606,9 +637,8 @@ SIMDE_TEST_GENERATE_ASSERT_EQUAL_FUNC_(uint64_t, u64, PRIu64)
  * test suite.  It doesn't use munit, or any other dependencies so
  * it's easy to use with creduce. */
 #if defined(SIMDE_TEST_BARE)
-  typedef int (* SimdeTestFunc)(void);
-  #define SIMDE_TEST_FUNC_LIST_BEGIN static SimdeTestFunc test_suite_tests[] = {
-  #define SIMDE_TEST_FUNC_LIST_ENTRY(name) test_simde_##name,
+  #define SIMDE_TEST_FUNC_LIST_BEGIN static const struct { int (* func)(void); const char* name; } test_suite_tests[] = {
+  #define SIMDE_TEST_FUNC_LIST_ENTRY(name) { test_simde_##name, #name },
   #define SIMDE_TEST_FUNC_LIST_END };
   #define SIMDE_MUNIT_TEST_ARGS void
 #else
@@ -616,6 +646,7 @@ SIMDE_TEST_GENERATE_ASSERT_EQUAL_FUNC_(uint64_t, u64, PRIu64)
   SIMDE_DIAGNOSTIC_DISABLE_CPP98_COMPAT_PEDANTIC_
   SIMDE_DIAGNOSTIC_DISABLE_OLD_STYLE_CAST_
   SIMDE_DIAGNOSTIC_DISABLE_VARIADIC_MACROS_
+  SIMDE_DIAGNOSTIC_DISABLE_RESERVED_ID_MACRO_
   #include "munit/munit.h"
   HEDLEY_DIAGNOSTIC_POP
 
